@@ -2,10 +2,10 @@
 #include "mainwindow.h"
 
 #include <QtCore/QDebug>
-#include <QtGui/QHBoxLayout>
-#include <QtWebKit/QWebView>
+#include <QHBoxLayout>
+#include <QWebView>
 
-#include <grantlee_core.h>
+#include <grantlee_templates.h>
 #include "grantlee_paths.h"
 
 #include "localrequestmanager.h"
@@ -31,5 +31,3 @@ MainWindow::MainWindow(QWidget* parent)
 
   layout->addWidget(wv);
 }
-
-#include "mainwindow.moc"
